@@ -14,13 +14,15 @@
  * limitations under the License.
  */
 
+#include <latch>
+
 #include "wangle/bootstrap/ClientBootstrap.h"
 #include "wangle/bootstrap/ServerBootstrap.h"
 #include "wangle/channel/Handler.h"
 
-#include <boost/thread.hpp>
 #include <folly/experimental/TestUtil.h>
 #include <folly/portability/GTest.h>
+#include <folly/synchronization/Latch.h>
 #include <glog/logging.h>
 
 using namespace wangle;
@@ -65,7 +67,7 @@ class TestAcceptor : public Acceptor {
   EventBase base_;
 
  public:
-  TestAcceptor() : Acceptor(ServerSocketConfig()) {
+  TestAcceptor() : Acceptor(std::make_shared<ServerSocketConfig>()) {
     Acceptor::init(nullptr, &base_);
   }
   void onNewConnection(
@@ -166,15 +168,15 @@ TEST(Bootstrap, ServerAcceptGroupTest) {
   SocketAddress address;
   server.getSockets()[0]->getAddress(&address);
 
-  boost::barrier barrier(2);
+  folly::Latch barrier(2);
   auto thread = std::thread([&]() {
     TestClient client;
     client.pipelineFactory(std::make_shared<TestClientPipelineFactory>());
     client.connect(address);
     EventBaseManager::get()->getEventBase()->loop();
-    barrier.wait();
+    barrier.arrive_and_wait();
   });
-  barrier.wait();
+  barrier.arrive_and_wait();
   server.stop();
   thread.join();
   server.join();
@@ -290,8 +292,8 @@ std::atomic<int> connections{0};
 class TestHandlerPipeline : public InboundHandler<AcceptPipelineType> {
  public:
   void read(Context* ctx, AcceptPipelineType conn) override {
-    if (conn.type() == typeid(ConnEvent)) {
-      auto connEvent = boost::get<ConnEvent>(conn);
+    if (std::holds_alternative<ConnEvent>(conn)) {
+      auto connEvent = std::get<ConnEvent>(conn);
       if (connEvent == ConnEvent::CONN_ADDED) {
         connections++;
       }
